# Do a systemd-based build from F-15; otherwise, a sysvinit-based build
%global use_systemd %([ "(" 0%{?fedora} -gt 14 ")" -o "(" 0%{?rhel} -gt 6 ")" ] && echo 1 || echo 0)
 
# This macro only defined by default around Fedora 10 time
%{!?_initddir:%global _initddir %{_initrddir}}

# With systemd, the run directory is /run; otherwise it's /var/run
%if %{use_systemd}
%global rundir /run
%else
%global rundir %{_localstatedir}/run
%endif

Summary:	Mail filter for sender address validation
Name:		smf-sav
Version:	1.4.0
Release:	5%{?dist}
License:	GPLv2+
Group:		System Environment/Daemons
URL:		http://smfs.sourceforge.net/smf-sav.html
Source0:	http://downloads.sf.net/project/smfs/smf-sav/smf-sav-%{version}/smf-sav-%{version}.tar.gz
Source1:	smf-sav.sysv
Source2:	smf-sav.service
Source3:	smfs.conf
Source4:	README.rpm
Patch0:		http://bubble.nsys.by/projects/patches/smf-sav/smf-sav-%{version}-bubble.patch
Patch1:		smf-sav-1.4.0-nostrip.patch
Patch5:		smf-sav-1.4.0-rundir.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildRequires:	sendmail-devel
Requires(pre):	/usr/bin/getent, /usr/sbin/groupadd, /usr/sbin/useradd, /usr/sbin/usermod
%if %{use_systemd}
BuildRequires:	systemd-units
Requires(post):	systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units
%else
Requires(post):	/sbin/chkconfig
Requires(preun): /sbin/chkconfig, initscripts
Requires(postun): initscripts
%endif

%description
A lightweight, fast and reliable milter that implements a real-time sender
address verification technology. This technology can stop some kinds of spam
with spoofed sender's email addresses. Also it implements a real-time
recipient address verification technology. It can be useful if your machine
is a backup MX for the recipients' domains or if your machine forwards all
email messages as a relay host for your domains to another internal or
external email servers. 

%prep
%setup -q

# Copy in additional sources
cp -a %{SOURCE1} %{SOURCE2} %{SOURCE3} %{SOURCE4} .

# Miscellaneous third-party enhancements
%patch0 -p1

# Don't strip the binary so we get usable debuginfo
%patch1 -p1

# Use /run rather than /var/run with systemd
%if %{use_systemd}
%patch5 -p1
%endif

%build
make %{?_smp_mflags} \
	DATADIR="%{rundir}/smfs" \
	CFLAGS="%{optflags} -pthread" \
	LDFLAGS="-lmilter -lpthread -lresolv"

%install
rm -rf %{buildroot}
install -d -m 700 %{buildroot}%{rundir}/smfs
install -Dp -m 755 smf-sav %{buildroot}%{_sbindir}/smf-sav
install -Dp -m 644 smf-sav.conf %{buildroot}%{_sysconfdir}/mail/smfs/smf-sav.conf
%if %{use_systemd}
# Install systemd unit file and tmpfiles.d configuration for /run/smfs
install -Dp -m 644 smf-sav.service %{buildroot}%{_unitdir}/smf-sav.service
install -Dp -m 644 smfs.conf %{buildroot}%{_prefix}/lib/tmpfiles.d/smfs.conf
%else
# Install SysV initscript
install -Dp -m 755 smf-sav.sysv %{buildroot}%{_initddir}/smf-sav
%endif

# Create dummy socket for %%ghost-ing
: > %{buildroot}%{rundir}/smfs/smf-sav.sock

%clean
rm -rf %{buildroot}

%pre
/usr/bin/getent group smfs >/dev/null || /usr/sbin/groupadd -r smfs
/usr/bin/getent passwd smfs >/dev/null || \
	/usr/sbin/useradd -r -g smfs -d %{_localstatedir}/lib/smfs \
		-s /sbin/nologin -c "Smart Sendmail Filters" smfs
exit 0

%post
if [ $1 -eq 1 ]; then 
	# Initial installation 
%if %{use_systemd}
	/bin/systemctl daemon-reload &>/dev/null || :
%else
	/sbin/chkconfig --add smf-sav || :
%endif
fi

%preun
if [ $1 -eq 0 ]; then
	# Package removal, not upgrade
%if %{use_systemd}
	/bin/systemctl --no-reload disable smf-sav.service &>/dev/null || :
	/bin/systemctl stop smf-sav.service &>/dev/null || :
%else
	%{_initddir}/smf-sav stop &>/dev/null || :
	/sbin/chkconfig --del smf-sav || :
%endif
fi

%postun
%if %{use_systemd}
/bin/systemctl daemon-reload &>/dev/null || :
%endif
if [ $1 -ge 1 ]; then
	# Package upgrade, not uninstall
%if %{use_systemd}
	/bin/systemctl try-restart smf-sav.service &>/dev/null || :
%else
	%{_initddir}/smf-sav condrestart &>/dev/null || :
%endif
fi

%files
%defattr(-,root,root,-)
%doc ChangeLog COPYING readme README.rpm
%{_sbindir}/smf-sav
%dir %{_sysconfdir}/mail/smfs/
%config(noreplace) %{_sysconfdir}/mail/smfs/smf-sav.conf
%attr(0700,smfs,smfs) %dir %{rundir}/smfs/
%ghost %{rundir}/smfs/smf-sav.sock
%if %{use_systemd}
%{_prefix}/lib/tmpfiles.d/smfs.conf
%{_unitdir}/smf-sav.service
%else
%{_initddir}/smf-sav
%endif

%changelog
* Sun Jul 28 2013 Paul Howarth <paul@city-fan.org> 1.4.0-5
- Systemd detection was broken in F-19 so hardcode it instead

* Tue Jul  3 2012 Paul Howarth <paul@city-fan.org> 1.4.0-4
- Move tmpfiles.d config from %%{_sysconfdir} to %%{_prefix}/lib
- Delay start-up until after network

* Thu Sep 29 2011 Paul Howarth <paul@city-fan.org> 1.4.0-3
- Use presence of /run/lock to determine if init is systemd

* Tue Jul 12 2011 Paul Howarth <paul@city-fan.org> 1.4.0-2
- Switch to systemd configuration where appropriate
- Nobody else likes macros for commands

* Wed Jul 28 2010 Paul Howarth <paul@city-fan.org> 1.4.0-1
- Initial RPM version
